# pycalcpad

This package is a pip-installable binder to Calcpad, the awesome mathematical and engineering calculator software written by Ned Ganchovski.

To learn more about Calcpad, see here: [Calcpad.eu](www.calcpad.eu) en [on Github](https://github.com/Proektsoftbg/Calcpad/).
